PortState

Enum PortState 

pub enum PortState {
    Close,
    Open,
}
Represents the state of a single digital I/O port (e.g., relay).

Variants



Close

The port is inactive/relay OFF.



Open

The port is active/relay ON.

Implementations

Source

impl PortState

pub fn decode_from_holding_registers(word: Word) -> Self

Decodes a PortState from a single Modbus holding register value (Word).

Arguments
  • word: The Word (u16) value read from the Modbus register for this port.
Returns

The corresponding PortState.

Example
assert_eq!(PortState::decode_from_holding_registers(0x0000), PortState::Close);
assert_eq!(PortState::decode_from_holding_registers(0x0001), PortState::Open);