pub enum PortState {
Close,
Open,
}Expand description
Represents the state of a single digital I/O port (e.g., relay).
Variants
Implementations
Sourceimpl PortState
impl PortState
Sourcepub fn decode_from_holding_registers(word: Word) -> Self
pub fn decode_from_holding_registers(word: Word) -> Self
Decodes a PortState from a single Modbus holding register value (Word).
Arguments
word: TheWord(u16) value read from the Modbus register for this port.
Returns
The corresponding PortState.
Example
assert_eq!(PortState::decode_from_holding_registers(0x0000), PortState::Close);
assert_eq!(PortState::decode_from_holding_registers(0x0001), PortState::Open);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PortState
impl<'de> Deserialize<'de> for PortState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for PortState
Provides a human-readable string representation (“close” or “open”).
impl Display for PortState
Provides a human-readable string representation (“close” or “open”).
impl Copy for PortState
impl Eq for PortState
impl StructuralPartialEq for PortState