Struct PortsAll

pub struct PortsAll;
A zero-sized type providing constants for controlling all ports simultaneously.

Implementations

Source

impl PortsAll

pub const ADDRESS: u16 = 0u16

The address is used with Modbus function 0x06 (Write Single Register) for commands that affect all ports simultaneously, where the data that is written to this address determines the action (e.g. PortsAll::REG_DATA_SET_ALL_OPEN).

pub const REG_DATA_SET_ALL_OPEN: Word = 1_792u16

Register data value to open all ports simultaneously (turn all relays ON). This value should be written to PortsAll::ADDRESS.

pub const REG_DATA_SET_ALL_CLOSE: Word = 2_048u16

Register data value to close all ports simultaneously (turn all relays OFF). This value should be written to PortsAll::ADDRESS.