pub struct PortsAll;Expand description
A zero-sized type providing constants for controlling all ports simultaneously.
Implementations
Sourceimpl PortsAll
impl PortsAll
Sourcepub const ADDRESS: u16 = 0u16
pub const ADDRESS: u16 = 0u16
The address is used with Modbus function 0x06 (Write Single Register) for commands that affect
all ports simultaneously, where the data that is written to this address determines the action
(e.g. PortsAll::REG_DATA_SET_ALL_OPEN).
Sourcepub const REG_DATA_SET_ALL_OPEN: Word = 1_792u16
pub const REG_DATA_SET_ALL_OPEN: Word = 1_792u16
Register data value to open all ports simultaneously (turn all relays ON).
This value should be written to PortsAll::ADDRESS.
Sourcepub const REG_DATA_SET_ALL_CLOSE: Word = 2_048u16
pub const REG_DATA_SET_ALL_CLOSE: Word = 2_048u16
Register data value to close all ports simultaneously (turn all relays OFF).
This value should be written to PortsAll::ADDRESS.